==> agrosyst-web-1.1.1-sources.jar: fr/inra/agrosyst/web/actions/domains/GetRefLocationJson.java <==
package fr.inra.agrosyst.web.actions.domains;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: GetRefLocationJson.java 3150 2014-02-07 08:55:29Z athimel $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.1.1/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/domains/GetRefLocationJson.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import java.util.Map;

import com.google.common.base.Objects;
import com.google.common.base.Strings;
import com.google.common.collect.ImmutableMap;

import fr.inra.agrosyst.api.entities.referential.RefLocation;
import fr.inra.agrosyst.api.services.referential.ReferentialService;
import fr.inra.agrosyst.web.actions.AbstractJsonAction;


/**
 * Action d'afficher les information de localisation.
 * 
 * @author David Cossé
 */
public class GetRefLocationJson extends AbstractJsonAction {

    private static final long serialVersionUID = 1L;
    
//    private static final Log log = LogFactory.getLog(GetRefLocationJson.class);

    protected transient ReferentialService referentialService;

    public void setReferentialService(ReferentialService referentialService) {
        this.referentialService = referentialService;
    }

    protected String locationTopiaId;

    protected String departement;
    protected String departementName;
    protected String petiteRegionAgricole;
    protected String petiteRegionAgricoleName;
    protected int region;

    public void setLocationTopiaId(String locationTopiaId) {
        this.locationTopiaId = locationTopiaId;
    }

    protected String orNC(String text) {
        String result = Objects.firstNonNull(text, "n/c");
        return result;
    }

    @Override
    public String execute() throws Exception {

        RefLocation refLocation = referentialService.getRefLocation(locationTopiaId);

        departement = refLocation.getDepartement();
        String key = "departement." + Strings.padStart(departement, 2, '0');
        departementName = getText(key, "n/c");
        petiteRegionAgricole = orNC(refLocation.getPetiteRegionAgricoleCode());
        petiteRegionAgricoleName = orNC(refLocation.getPetiteRegionAgricoleNom());
        region = refLocation.getRegion();

        return SUCCESS;
    }

    @Override
    public Object getJsonData() {
        Map<String, String> result = ImmutableMap.of(
                "departement", departement,
                "departementName", departementName,
                "petiteRegionAgricole", petiteRegionAgricole,
                "petiteRegionAgricoleName", petiteRegionAgricoleName,
                "region", String.valueOf(region)
        );
        return result;
    }

}

==> agrosyst-web-1.4.1-sources.jar: fr/inra/agrosyst/web/actions/domains/GetRefLocationJson.java <==
package fr.inra.agrosyst.web.actions.domains;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: GetRefLocationJson.java 4318 2014-09-10 15:57:14Z athimel $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.4.1/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/domains/GetRefLocationJson.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import java.util.Map;

import com.google.common.base.MoreObjects;
import com.google.common.base.Strings;
import com.google.common.collect.ImmutableMap;

import fr.inra.agrosyst.api.entities.referential.RefLocation;
import fr.inra.agrosyst.api.services.referential.ReferentialService;
import fr.inra.agrosyst.web.actions.AbstractJsonAction;


/**
 * Action d'afficher les information de localisation.
 * 
 * @author David Cossé
 */
public class GetRefLocationJson extends AbstractJsonAction {

    private static final long serialVersionUID = 1L;
    
//    private static final Log log = LogFactory.getLog(GetRefLocationJson.class);

    protected transient ReferentialService referentialService;

    public void setReferentialService(ReferentialService referentialService) {
        this.referentialService = referentialService;
    }

    protected String locationTopiaId;

    protected String departement;
    protected String departementName;
    protected String petiteRegionAgricole;
    protected String petiteRegionAgricoleName;
    protected int region;

    public void setLocationTopiaId(String locationTopiaId) {
        this.locationTopiaId = locationTopiaId;
    }

    protected String orNC(String text) {
        String result = MoreObjects.firstNonNull(text, "n/c");
        return result;
    }

    @Override
    public String execute() throws Exception {

        RefLocation refLocation = referentialService.getRefLocation(locationTopiaId);

        departement = refLocation.getDepartement();
        String key = "departement." + Strings.padStart(departement, 2, '0');
        departementName = getText(key, "n/c");
        petiteRegionAgricole = orNC(refLocation.getPetiteRegionAgricoleCode());
        petiteRegionAgricoleName = orNC(refLocation.getPetiteRegionAgricoleNom());
        region = refLocation.getRegion();

        return SUCCESS;
    }

    @Override
    public Object getJsonData() {
        Map<String, String> result = ImmutableMap.of(
                "departement", departement,
                "departementName", departementName,
                "petiteRegionAgricole", petiteRegionAgricole,
                "petiteRegionAgricoleName", petiteRegionAgricoleName,
                "region", String.valueOf(region)
        );
        return result;
    }

}
